pub struct AcceptOfferResponse {
pub contract_id: String,
pub counter_party: String,
pub accept_dlc: Vec<u8>,
}Fields
contract_id: Stringcounter_party: Stringaccept_dlc: Vec<u8>Trait Implementations
Sourceimpl Clone for AcceptOfferResponse
impl Clone for AcceptOfferResponse
Sourcefn clone(&self) -> AcceptOfferResponse
fn clone(&self) -> AcceptOfferResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AcceptOfferResponse
impl Debug for AcceptOfferResponse
Sourceimpl Default for AcceptOfferResponse
impl Default for AcceptOfferResponse
Sourceimpl<'de> Deserialize<'de> for AcceptOfferResponse
impl<'de> Deserialize<'de> for AcceptOfferResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AcceptOfferResponse
impl Hash for AcceptOfferResponse
Sourceimpl Message for AcceptOfferResponse
impl Message for AcceptOfferResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AcceptOfferResponse
impl PartialEq for AcceptOfferResponse
Sourcefn eq(&self, other: &AcceptOfferResponse) -> bool
fn eq(&self, other: &AcceptOfferResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AcceptOfferResponse
impl Serialize for AcceptOfferResponse
impl Eq for AcceptOfferResponse
impl StructuralPartialEq for AcceptOfferResponse